@@ -20,8 +20,7 @@ class TestCluster(unittest.TestCase):
     @unittest.skipUnless(integration_test_ready(), "Integration test environment is not configured")
     def test_crud_namespace(self):
         # given
-        s = Staroid(access_token=os.environ["STAROID_ACCESS_TOKEN"], org=os.environ["STAROID_ACCOUNT"])
-        all_orgs = s.get_all_orgs()
+        s = Staroid(access_token=os.environ["STAROID_ACCESS_TOKEN"], account=os.environ["STAROID_ACCOUNT"])
         c = s.cluster().create("staroid-python it-test-namespace")
 
         # when create a namespace
@@ -32,7 +31,32 @@ class TestCluster(unittest.TestCase):
         wait_for_phase(ns_api, ns, "RUNNING")
         self.assertEqual("RUNNING", ns_api.get_by_id(ns.id()).phase())
 
-        # when stop a namespace
+        # start shell
+        ns_api.shell_start("instance1")
+
+        resources = ns_api.get_all_resources("instance1")
+        self.assertTrue(len(resources["services"]) > 0)
+
+        # start tunnel
+        ns_api.start_tunnel("instance1", ["57683:localhost:57683"])
+
+        # stop tunnel
+        ns_api.stop_tunnel("instance1")
+
+        # stop shell
+        ns_api.shell_stop("instance1")
+
+        # pause
+        ns = ns_api.stop("instance1")
+        wait_for_phase(ns_api, ns, "PAUSED")
+        self.assertEqual("PAUSED", ns_api.get_by_id(ns.id()).phase())
+
+        # resume
+        ns = ns_api.start("instance1")
+        wait_for_phase(ns_api, ns, "RUNNING")
+        self.assertEqual("RUNNING", ns_api.get_by_id(ns.id()).phase())
+
+        # when delete a namespace
         ns = ns_api.delete("instance1")
 
         # then namespace becomes REMOVED
